# SUS02-BP02: Align SLAs with sustainability goals

## Description

Consider sustainability trong SLA definitions.

## Implementation Guidance

- Review if SLAs require excessive resources
- Consider relaxing non-critical SLAs
- Balance performance vs sustainability
- Document sustainability trade-offs
- Communicate with stakeholders

## Risk Level

Low - Aggressive SLAs may waste resources.

## Related Best Practices

- [SUS02-BP01](SUS02-BP01-Dynamic-Scaling.md)
- [REL06-BP02](../../03-REL/REL06-Change-Resource-Monitoring/REL06-BP02-Define-Calculate-Metrics.md)
